@@ -12,7 +12,7 @@ use warnings;
 
 package Dist::Zilla::Plugin::Git::Tag;
 BEGIN {
-  $Dist::Zilla::Plugin::Git::Tag::VERSION = '1.101680';
+  $Dist::Zilla::Plugin::Git::Tag::VERSION = '1.101800';
 }
 # ABSTRACT: tag the new version
 
@@ -39,7 +39,7 @@ with 'Dist::Zilla::Role::AfterRelease';
 
 has tag_format  => ( ro, isa=>Str, default => 'v%v' );
 has tag_message => ( ro, isa=>Str, default => 'v%v' );
-
+has branch => ( ro, isa=>Str, predicate=>'has_branch' );
 
 # -- role implementation
 
@@ -61,10 +61,11 @@ sub after_release {
     my @opts = $self->tag_message
         ? ( '-m' => _format_tag($self->tag_message, $self->zilla) )
         : ();
+    my @branch = $self->has_branch ? ( $self->branch ) : ();
 
     # create a tag with the new version
     my $tag = _format_tag($self->tag_format, $self->zilla);
-    $git->tag( @opts, $tag );
+    $git->tag( @opts, $tag, @branch );
     $self->log("Tagged $tag");
 }
 
@@ -79,7 +80,7 @@ Dist::Zilla::Plugin::Git::Tag - tag the new version
 
 =head1 VERSION
 
-version 1.101680
+version 1.101800
 
 =head1 SYNOPSIS
 
@@ -101,37 +102,46 @@ doesn't already exist.  (You would have to manually delete the
 existing tag before you could release the same version again, but that
 is almost never a good idea.)
 
+=head2 Plugin options
+
 The plugin accepts the following options:
 
 =over 4
 
-=item * tag_format - format of the tag to apply. Defaults to C<v%v>.
+=item * tag_format - format of the tag to apply. Defaults to C<v%v>, see
+C<Formatting options> below.
 
-=item * tag_message - format of the commit message. Defaults to C<v%v>.
-Use C<tag_message = > to create a lightweight tag.
+=item * tag_message - format of the commit message. Defaults to C<v%v>,
+see C<Formatting options> below. Use C<tag_message = > to create a
+lightweight tag.
+
+=item * branch - which branch to tag. Defaults to current branch.
 
 =back
 
-You can use the following codes in both options:
+=head2 Formatting options
+
+Some plugin options allow you to customize the tag content. You can use
+the following codes at your convenience:
 
 =over 4
 
 =item C<%{dd-MMM-yyyy}d>
 
 The current date.  You can use any CLDR format supported by
-L<DateTime>.  A bare C<%d> means C<%{dd-MMM-yyyy}d>.
+L<DateTime>. A bare C<%d> means C<%{dd-MMM-yyyy}d>.
 
 =item C<%n>
 
-a newline
+A newline
 
 =item C<%N>
 
-the distribution name
+The distribution name
 
 =item C<%v>
 
-the distribution version
+The distribution version
 
 =back
 
